@@ -1,5 +1,6 @@
-testthat::test_that("integrated_multilevel_model_summary: lme4 model", {
-  expect_warning(summary <- integrated_multilevel_model_summary(
+testthat::test_that("lme_multilevel_model_summary: lme4 model", {
+  suppressWarnings(
+    summary <- lme_multilevel_model_summary(
     data = popular,
     response_variable = popular,
     random_effect_factors = extrav,
@@ -28,8 +29,8 @@ testthat::test_that("integrated_multilevel_model_summary: lme4 model", {
   expect_false(is.null(summary$simple_slope$jn_plot))
 })
 
-testthat::test_that("integrated_multilevel_model_summary: lmerTest model", {
-  expect_warning(summary <- integrated_multilevel_model_summary(
+testthat::test_that("lme_multilevel_model_summary: lmerTest model", {
+  suppressWarnings(summary <- lme_multilevel_model_summary(
     data = popular,
     response_variable = popular,
     random_effect_factors = extrav,
@@ -59,8 +60,8 @@ testthat::test_that("integrated_multilevel_model_summary: lmerTest model", {
 })
 
 
-testthat::test_that("integrated_multilevel_model_summary: nlme model", {
-  expect_warning(summary <- integrated_multilevel_model_summary(
+testthat::test_that("lme_multilevel_model_summary: nlme model", {
+  suppressWarnings(summary <- lme_multilevel_model_summary(
     data = popular,
     response_variable = popular,
     random_effect_factors = extrav,
@@ -88,22 +89,3 @@ testthat::test_that("integrated_multilevel_model_summary: nlme model", {
   expect_true(is.null(summary$simple_slope$simple_slope_df)) # unable to compute simple slope
   expect_true(is.null(summary$simple_slope$jn_plot))
 })
-
-testthat::test_that("integrated_multilevel_model_summary:debug", {
-  summary <- suppressWarnings(integrated_multilevel_model_summary(
-    data = popular,
-    response_variable = popular,
-    random_effect_factors = extrav,
-    non_random_effect_factors = c(sex, texp),
-    three_way_interaction_factor = c(extrav, sex, texp),
-    graph_label_name = c("popular", "extraversion", "sex", "teacher experience"), # change interaction plot label
-    id = class,
-    quite = T,
-    model_summary = TRUE,
-    interaction_plot = TRUE,
-    assumption_plot = TRUE,
-    simple_slope = TRUE,
-    plot_color = TRUE
-  ))
-  expect_equal(summary, NULL)
-})
